Learn R Programming

TFunHDDC (version 1.0.2)

fitNOxBenchmark: fitNOxBenchmark

Description

Extract NOx data from fda.usc

Usage

fitNOxBenchmark(nbasis=15)

Value

fd

A functional data object representing the fitted NOx data.

groupd

Group classifications for each curve as a curve representing a weekday or weekend/festive day.

Arguments

nbasis

The number of basis functions to fit to the simulated data.

Author

Cristina Anton and Iain Smith

Details

Open NOx data from the poblenou data set of fda.usc. Fit the data to a given number of basis functions and adjust classes for festive days into just weekdays and weekends.

References

- Febrero-Bande M, Galeano P, Gonz~alez-Manteiga W (2008) Outlier detection in functional data by depth measures, with application to identify abnormal nox levels. Environmetrics 19:331-345. <//doi.org/10.1002/env.878>.

- Cristina Anton, Iain Smith Model-based clustering of functional data via mixtures of \(t\) distributions. Advances in Data Analysis and Classification (to appear).

See Also

plotNOx

Examples

Run this code
# Univariate Contaminated Data
data1<-fitNOxBenchmark(15)
plotNOx(data1)

Run the code above in your browser using DataLab